==> freecad_0.16.6712%2Bdfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_pt-PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt-PT" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Ajustes Gerais</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Definições Gerais do OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD executável</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executeable</source>
      <translation>O caminho para o OpenSCAD executável</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Importar OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Usar o ViewProvider na vista de árvore</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Se marcado, os objetos Multimatrix serão paramétricos</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Usar Multmatrix</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>O número máximo de faces de um polígono,  prisma ou  tronco. Se fn é superior a este valor, o objeto é considerado uma circular. Definir como 0 para sem limite</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Número máximo de faces de polígonos (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Exportar OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>tamanho máximo do fragmento</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>minimum angle for a fragment</source>
      <translation>ângulo mínimo para um fragmento</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>angular (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>minimum size of a fragment</source>
      <translation>tamanho mínimo de um fragmento</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>tamanho (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>convexidade</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Malha de emergência</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Deflexão</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>deflexão</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Definições de Triangulação</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Se esta opção for marcada, os objetos vão agrupar seus descendentes na árvore</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Imprimir informações de depuração na Consola</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="141"/>
      <source>Convert Edges to Faces</source>
      <translation>Converter Arestas para Faces</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="220"/>
      <source>Please select 3 objects first</source>
      <translation>Por favor, selecione primeiro 3 objetos</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1118"/>
      <source>Unsupported Function</source>
      <translation>Função não Suportada</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1118"/>
      <source>Press OK</source>
      <translation>Pressione OK</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="264"/>
      <source>Add</source>
      <translation>Adicionar</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="265"/>
      <source>Clear</source>
      <translation>Limpar</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="266"/>
      <source>as Mesh</source>
      <translation>como malha (mesh)</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="267"/>
      <source>Add OpenSCAD Element</source>
      <translation>Adicionar elemento OpenSCAD</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="340"/>
      <source>Perform</source>
      <translation>Executar</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="341"/>
      <source>Mesh Boolean</source>
      <translation>Malha booleana</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="560"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Erro: todas as formas devem ser 2D ou todas devem ser 3D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="91"/>
      <source>Unable to explode %s</source>
      <translation>Não é possível explodir %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="382"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Adicionar elemento OpenSCAD...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="384"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Adicionar um elemento de OpenSCAD inserindo código OpenSCAD e executando o aplicativo OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="118"/>
      <source>Color Shapes</source>
      <translation>Formas de cor</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="120"/>
      <source>Color Shapes by validity and type</source>
      <translation>Formas de cor pela validade e tipo</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="139"/>
      <source>Convert Edges To Faces</source>
      <translation>Converter arestas em faces</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="200"/>
      <source>Expand Placements</source>
      <translation>Expandir posição</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="202"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Expandir todos os posicionamentos para baixo na árvore</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="100"/>
      <source>Explode Group</source>
      <translation>Explodir grupo</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>remove fusion, apply placement to children and color randomly</source>
      <translation>remover a fusão, aplicar posição para descendentes e cor aleatoriamente</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="417"/>
      <source>Hull</source>
      <translation>Casca</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="419"/>
      <source>Perform Hull</source>
      <translation>Executar casca</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="181"/>
      <source>Increase Tolerance Feature</source>
      <translation>Aumentar tolerância</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="183"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Criar um objeto que permita aumentar a tolerância</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="396"/>
      <source>Mesh Boolean...</source>
      <translation>Malha Booleana...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="398"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation.</source>
      <translation>Exportar objetos como malhas e usar OpenSCAD para executar uma operação booleana.</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="438"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="440"/>
      <source>Perform Minkowski</source>
      <translation>Executar Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="160"/>
      <source>Refine Shape Feature</source>
      <translation>Refinar forma</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="162"/>
      <source>Create Refine Shape Feature</source>
      <translation>Criar um objeto forma refinado</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="239"/>
      <source>Remove Objects and their Children</source>
      <translation>Remover objetos e seus dependentes</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="241"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Remove os objetos selecionados e todos os dependentes que não são referenciadas por outros objetos</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Replace Object</source>
      <translation>Substituir  objeto</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="226"/>
      <source>Replace an object in the Feature Tree. Please select old, new and parent object</source>
      <translation>Substitui um objeto na árvore de recursos. Por favor selecione o anterior, novo e objeto origem</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="80"/>
      <source>OpenSCAD Part tools</source>
      <translation>Ferramentas de peça (part) OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="78"/>
      <source>OpenSCADTools</source>
      <translation>OpenSCADTools</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_pt-PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="pt-PT" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Ajustes Gerais</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Definições Gerais do OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>OpenSCAD executável</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Importar OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Usar o ViewProvider na vista de árvore</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Se marcado, os objetos Multimatrix serão paramétricos</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Usar Multmatrix</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>O número máximo de faces de um polígono,  prisma ou  tronco. Se fn é superior a este valor, o objeto é considerado uma circular. Definir como 0 para sem limite</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Número máximo de faces de polígonos (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Exportar OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>tamanho máximo do fragmento</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>angular (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>tamanho (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>convexidade</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Malha de emergência</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Deflexão</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>deflexão</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Definições de Triangulação</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Se esta opção for marcada, os objetos vão agrupar seus descendentes na árvore</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>Imprimir informações de depuração na Consola</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>O caminho para o executável do OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Ângulo mínimo para um fragmento</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Tamanho mínimo de um fragmento</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="149"/>
      <source>Convert Edges to Faces</source>
      <translation>Converter Arestas para Faces</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="309"/>
      <source>Please select 3 objects first</source>
      <translation>Por favor, selecione primeiro 3 objetos</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Unsupported Function</source>
      <translation>Função não Suportada</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Press OK</source>
      <translation>Pressione OK</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="347"/>
      <source>Add</source>
      <translation>Adicionar</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="348"/>
      <source>Clear</source>
      <translation>Limpar</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="349"/>
      <source>as Mesh</source>
      <translation>como malha (mesh)</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="350"/>
      <source>Add OpenSCAD Element</source>
      <translation>Adicionar elemento OpenSCAD</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="423"/>
      <source>Perform</source>
      <translation>Executar</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="424"/>
      <source>Mesh Boolean</source>
      <translation>Malha booleana</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="623"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Erro: todas as formas devem ser 2D ou todas devem ser 3D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>Unable to explode %s</source>
      <translation>Não é possível explodir %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="464"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Adicionar elemento OpenSCAD...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="468"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Adicionar um elemento de OpenSCAD inserindo código OpenSCAD e executando o aplicativo OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="126"/>
      <source>Color Shapes</source>
      <translation>Formas de cor</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="129"/>
      <source>Color Shapes by validity and type</source>
      <translation>Formas de cor pela validade e tipo</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="146"/>
      <source>Convert Edges To Faces</source>
      <translation>Converter arestas em faces</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="291"/>
      <source>Expand Placements</source>
      <translation>Expandir posição</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="294"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Expandir todos os posicionamentos para baixo na árvore</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="110"/>
      <source>Explode Group</source>
      <translation>Explodir grupo</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="113"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Remover a fusão, aplicar posição aos descendentes e cor aleatoriamente</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="497"/>
      <source>Hull</source>
      <translation>Casca</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="500"/>
      <source>Perform Hull</source>
      <translation>Executar casca</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="274"/>
      <source>Increase Tolerance Feature</source>
      <translation>Aumentar tolerância</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="277"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Criar um objeto que permita aumentar a tolerância</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="477"/>
      <source>Mesh Boolean...</source>
      <translation>Malha Booleana...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="481"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Exportar objetos como malhas e usar OpenSCAD para executar uma operação booleana</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="516"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="519"/>
      <source>Perform Minkowski</source>
      <translation>Executar Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="195"/>
      <source>Mirror Mesh Feature...</source>
      <translation>Espelhar recurso da malha...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="198"/>
      <source>Create Mirror Mesh Feature</source>
      <translation>Criar Recurso Espelho de Malha</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="165"/>
      <source>Refine Shape Feature</source>
      <translation>Refinar forma</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="168"/>
      <source>Create Refine Shape Feature</source>
      <translation>Criar um objeto forma refinado</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="324"/>
      <source>Remove Objects and their Children</source>
      <translation>Remover objetos e seus dependentes</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="327"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Remove os objetos selecionados e todos os dependentes que não são referenciadas por outros objetos</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="312"/>
      <source>Replace Object</source>
      <translation>Substituir  objeto</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="315"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Substituir um objeto na árvore de recursos. Por favor, selecione o antigo, o novo e o objeto pai</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="254"/>
      <source>Resize Mesh Feature...</source>
      <translation>Redimensionar recurso da malha...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="258"/>
      <source>Create Resize Mesh Feature</source>
      <translation>Criar Recurso Redimensionar Malha</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Scale Mesh Feature...</source>
      <translation>Escalar Recurso da Malha...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="228"/>
      <source>Create Scale Mesh Feature</source>
      <translation>Criar Recurso Redimensionar Malha</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="83"/>
      <source>OpenSCAD Part tools</source>
      <translation>Ferramentas de peça (part) OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="81"/>
      <source>OpenSCADTools</source>
      <translation>OpenSCADTools</translation>
    </message>
  </context>
</TS>
